C grcpar.F
C All parameters that users are allowed to change are given by subroutines
C in this file.
C----------------------------------------------------------------------------
C SUBROUTINE GRCPAR : BASES parameters.
C
C IBSWRT = 0 : Create a new output file.
C        = 1 : Use an existing output file; i.e. skip the integration.
C ICOUP      : Choice of the energy scale (Q^2) for couplings.
C              if ICOUP = 1  ==> Q^2 = s-hat of the hard interaction.
C                       = 2  ==> Q^2 = average mT^2  (<mT^2>).
C                       = 3  ==> Q^2 = total mT^2  (sum mT^2).
C                       = 4  ==> Q^2 = maximum mT^2  (max mT^2).
C                       = 5  ==> Q^2 = a constant value.
C                       = 6  ==> user-defined Q^2.
C IFACT      : Choice of the energy scale (Q^2) for PDF.
C              The definition is the same as icoup.
C              If this is not given explicitly,
C                       = 0  ==> same scale as "ICOUP".
C IGRCGEF    : ON/OFF: 0/1 for photon interference in Z/A productions.
C GRCQ       : Renormalization scale in GeV; effective only when ICOUP = 5.
C GRCFAQ     : Factorization scale in GeV; effective only when IFACT = 5.
C NCALL      : Number of sampling points in each iteration step.
C GRCFILE    : BASES output file name.
C----------------------------------------------------------------------------
C SUBROUTINE SETMAS : particle masses and widths.
C
C AMZ        : Z mass               AGZ        : Z width
C AMW        : W mass               AGW        : W width
C AMH        : SM Higgs mass        AGH        : SM Higgs width
C AMUQ(I) and AGUQ(I) for the up-type quarks (u, c and t), and AMDQ(I) and
C AGDQ(I) for the down-type quarks (d, s and b), respectively.
C----------------------------------------------------------------------------
C SUBROUTINE GRCUSRSETQ : user-defined energy scale.
C
C The definition is effective only when "ICOUP" or "IFACT" = 6.
C Users must set their-defined energy scale into "GRCQ" or "GRCFAQ".
C An example is shown to choose as Q = <mT> of top-quarks in the top pair 
C productions ([ISUB]=170).
C----------------------------------------------------------------------------
C SUBROUTINE GRCUSRCUT : user-defined kinematical cut.
C
C The returned argument is "IUSRCUT".
C If events pass their cuts, IUSRCUT = 0,
C       not pass             IUSRCUT = 1.
C Users must carefully check the convergence of the BASES iteration if they
C define a tight cut using this subroutine.
C----------------------------------------------------------------------------
C Kinematical variables provided for user-defined routines.
C See the include file, grchad.inc, for the details.
C
C Four-momentum in the CM frame of the hard interaction
C   i = 1, 2       : initial-state particles
C   i = 3, up to 8 : final-state particles
C     PGRC(1,i)  : px of i-th particle in CM frame.
C     PGRC(2,i)  : py
C     PGRC(3,i)  : pz
C     PGRC(4,i)  : E
C
C Variables in the laboratory frame
C   initial-state particles (i = 1, 2)
C     PLGRC(1,i) : px
C     PLGRC(2,i) : py
C     PLGRC(3,i) : pz
C     PLGRC(4,i) : E
C   final-state particles (i = 3,...,8)
C     PLGRC(1,i) : pT
C     PLGRC(2,i) : phi
C     PLGRC(3,i) : pseudo-rapidity (eta)
C     PLGRC(4,i) : E
C----------------------------------------------------------------------------
C  _/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
C _/_/  Set Initial Parameter for Each Process  _/_/
C_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
      SUBROUTINE GRCPAR(ISUB,GRCFILE)
      IMPLICIT REAL*8(A-H,O-Z)

      PARAMETER (MXDIM = 50, NDMX = 50 )
      COMMON /BPARM1/ XL(MXDIM),XU(MXDIM),NDIM,NWILD,
     $     IG(MXDIM),NCALL

      INCLUDE 'inclm.h'
      INCLUDE 'grchad.inc'
      INTEGER ISUB
      CHARACTER GRCFILE*60

C+================================================

      RETURN
      END
 
C  _/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
C _/_/  Set Mass, Width and some Parameters _/_/
C_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
      SUBROUTINE SETMAS
      IMPLICIT REAL*8(A-H,O-Z)
      INCLUDE 'inclm.h'
      INCLUDE 'inclc.h'
      INCLUDE 'grchad.inc'
      DOUBLE PRECISION WWIDTH,ZWIDTH,TWIDTH
      EXTERNAL WWIDTH,ZWIDTH,TWIDTH

C...Constants
      PI    = ACOS(- 1.0D0 )    ! pi
      PI2   = PI*PI             ! pi**2
      RAD   = PI/180.0D0        ! radian
      GEVPB = 0.38937966D9      ! GeV -> pb
 
C...Some paramters are re-calculated according to the option IGAUGE and ICOUP.
      ALPHA = 1.0D0/128.07D0    ! alpha_em(Mz)
      ALPHAS= 0.130D0           ! alpha_s (dummy)
      ALPHA0= 1.0D0/137.036D0   ! alpha_em(Q=0)
      GF    = 1.16639D-5        ! Fermi constant
      STH2  = 0.231D0           ! sin^2(theta_w)
 
C...Set Mass
      AMW = 80.419D0            ! W
      AMZ = 91.188D0            ! Z
      AMA = 0.0D0               ! photon
      AMG = 0.0D0               ! gluon
      AMH = 120.0D0             ! SM Higgs
CCC   AMH = 80.0D0
CCC   AMH = 160.0D0
 
      AMNU(1) = 0.0D0           ! electron neutrino
      AMNU(2) = 0.0D0           ! muon neutrino
      AMNU(3) = 0.0D0           ! tau neutrino
      AMLP(1) = 0.0D0           ! electron
      AMLP(2) = 0.0D0           ! muon
CCC      AMLP(1) = 0.51099906D-3   ! electron
CCC      AMLP(2) = 105.658389D-3   ! muon
      AMLP(3) = 1.7771D0        ! tau

      AMUQ(1) = 0.0D0           ! u quark
      AMUQ(2) = 1.5D0           ! c quark
      AMUQ(3) = 178.0D0         ! t quark
      AMDQ(1) = 0.0D0           ! d quark
      AMDQ(2) = 0.0D0           ! s quark
      AMDQ(3) = 4.75D0          ! b quark

C...Set Width
CCC   AGW = 2.1200d0            ! W from experiment.
      AGW = 2.048D0             ! W
      AGZ = 2.446D0             ! Z
CCC   AGW = WWIDTH(1)           ! To get theoretical width of W and Z 
CCC   AGZ = ZWIDTH(1)           ! 0:LO, 1:radiative correction.
 
      AGH = 6.5378773D-3        ! SM Higgs (Mh = 120 GEV)
CCC   AGH = 4.1610854d-3       ! SM Higgs (Mh = 80 GeV)
CCC   AGH = 6.0677468d-2       ! SM Higgs (Mh = 160 GeV)

      AGUQ(1) = 0.0D0           ! u quark
      AGUQ(2) = 0.0D0           ! c quark
      AGUQ(3) = 1.586882D0      ! t quark
CCC   AGUQ(3) = TWIDTH(1)       ! To get theoretical width of top.
      AGDQ(1) = 0.0D0           ! d quark
      AGDQ(2) = 0.0D0           ! s quark
      AGDQ(3) = 0.001D0         ! b quark
 
      RETURN
      END
 
 
C  _/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
C _/_/  Set User Defined Energy Scale   _/_/
C_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
      SUBROUTINE GRCUSRSETQ
      IMPLICIT REAL*8(A-H,O-Z)
      INCLUDE 'grchad.inc'
      INCLUDE 'inclm.h'
C...User-defined energy scale.
C
C   The definition is effective only when "ICOUP" or "IFACT" = 6.
C   Users must set their-defined energy scale into "GRCQ" or "GRCFAQ".
C
C...4-momentum in the CM frame of the hard interaction
C   PGRC(i,j)  (i=1,4:(px,py,pz,E)): 4-momentum of j-th particle.
C   PQGRC(i,j) (i=1,4:(px,py,pz,E)): 4-momentum of j-th resonance particle.
C
C   This example shows the way to take the avarage transeverse mass of two 
C   top-quark invariant system as the renormalization/factrization scale in 
C   the top pair productions (ISUB=170).
C
C   For 6-body kinematics, 4-momenta of (anti-)top quark are given in
C   a parameters : PQGRC(i,1) and PQGRC(i,2).

C...Top pT^2.
      PT2 = PQGRC(1,1)**2+PQGRC(2,1)**2

C...Top and Anti-top mass.
      TMAS  = AMUQ(3)**2

C...Avarage transeverse mass.
      GRCQ = SQRT(PT2+TMAS)
      GRCFAQ = GRCQ

      RETURN
      END
 
C  _/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
C _/_/  Set User Defined Cut  _/_/
C_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
      SUBROUTINE GRCUSRCUT(IUSRCUT)
      IMPLICIT NONE
      INCLUDE 'grchad.inc'
      INTEGER IUSRCUT
      INTEGER GRCKFCD
      EXTERNAL GRCKFCD
      DOUBLE PRECISION GRCIVMS,GRCDPHI,GRCDRCN
      EXTERNAL GRCIVMS,GRCDPHI,GRCDRCN
C...User-defined kinematic cuts.
C
C   The returned argument is "IUSRCUT".
C   If events pass their cuts, IUSRCUT = 0,
C         not pass             IUSRCUT = 1.
C
C   Users must carefully check the convergence of the BASES iteration 
C   if they define a tight cut using this subroutine.
C
C...4-momentum in the CM frame of the hard interaction
C     PGRC(I,J)  (I=1,4:(px,py,pz,E))  : 4-momentum of J-th particle.
C
C...4-momentum in the Laboratory frame.
C     PLGRC(I,J) (I=1,4:(pT,phi,eta,E)): 4-momentum of J-th (J > 2) 
C                                        final state particle.
C
C...Useful stuff.
C     FUNCTION GRCKFCD(I)   : Output particle identification code.
C     FUNCTION GRCIVMS(I,J) : Output inv. mass between "I" and "J" particles.
C     FUNCTION GRCDPHI(I,J) : Output Delta Phi between "I" and "J" particles.
C     FUNCTION GRCDRCN(I,J) : Output Delta R between "I" and "J" particles.
C
CCCC   This example shows the cuts of pT > 20 GeV and DeltaR > 0.4 only for 
CCCC   light flavors from top decay, but not applied the b-quarks from top.
CCC
CCCC...Initialzation.
CCC      IUSRCUT = 0
CCC
CCCC...Set cut vatiable.
CCC      PTCUT = 20.0D0
CCC      DRCUT = 0.4D0
CCC
CCCC...Look for light flavor, then check the kinematics.
CCC      DO I = 3,8
CCC         ID = GRCKFCD(I)
CCC         IF (IABS(ID).LT.5) THEN
CCC            IF (PLGRC(1,I).LT.PTCUT) IUSRCUT = 1
CCC            DO J = 3,8
CCC               IF (J.NE.I.AND.GRCDRCN(I,J).LT.DRCUT) IUSRCUT = 1
CCC            ENDDO
CCC         ENDIF
CCC      ENDDO

      IUSRCUT = 0
 
      RETURN
      END
 
